# To Do App (Proof of Concepts)

>NOTE: This project is no longer in active development. This was a semester project, as a proof of concept **(intending to use multiple components rather that a framework, which is a not a good idea, thus making this more of a proof of bad concepts)** and thus cannot be developed into something which is better that other products on the market

This app will help you to stay on top of your daily tasks. It shows you what you have to do and at the same time 
classifies the tasks for you to manage your responsibilities, work or just your wish to do something.

This app was created, not to be used in production, but far from it; it was made to show a proof of concept, which have been listed at [here at GitHub](https://github.com/enygmator/To-Do-PoC)

# Project Details:

Created by GROUP 10:
1. Moyank Giri
2. Vaibhava Krishna D
3. T Tarun Aditya (Lead developer and project manager)

"A Python Project"  
Semester 1 of batch 2019-23  
"UE19CS102" (Introduction to computing using python Lab) - Section M  
PES University, Bengaluru, Karnataka, India